@@ -95,7 +95,7 @@ scribeArg$methods(
     aliases = "",
     action  = arg_actions(),
     default = NULL,
-    convert = default_convert,
+    convert = scribe_convert(),
     n       = NA_integer_,
     info    = NA_character_,
     options = list(),
